
# Waveboxgen

### usage: 
    waveboxgen [-h] spawn service filepath

Generate a wavebox framework service file

### positional arguments:
    spawn, s      Pass this argument to generate file
    service, s    Pass this argument to create service file
    filepath      Directory where the service file will be generated

### options:
    -h, --help  show this help message and exit
